==> codelite-4.0.5589-gtk.src.tar.gz: codelite-4.0.5589/DatabaseExplorer/IDbAdapter.h <==
#ifndef IDBADAPTER_H
#define IDBADAPTER_H
#include <wx/wx.h>
#include <wx/dynarray.h>
#include <wx/dblayer/include/DatabaseLayer.h>
#include "IDbType.h"
//#include "columncol.h"
//#include "tablecol.h"
//#include "databasecol.h"
class DbConnection;
class Database;
class DBETable;
class View;
class IDbType;


/*! \brief Basic virtual class for creating universal interface between different database servers. */
class IDbAdapter {

public:
	enum TYPE {
		atUNKNOWN = 0,
		atSQLITE,
		atMYSQL,
		atPOSTGRES
	};
	
	/*! \brief Return opened DatabaseLayer for selected database. If dbName is empty, DatabaseLayer will be opend without defalut database. */
	virtual DatabaseLayer* GetDatabaseLayer(const wxString& dbName) = 0;
	
	/*! \brief Return true if dbAdapter is connected. DEPRECATED!!! */
	virtual bool IsConnected() = 0;
	
	/*! \brief Clone DbAdapter and return new object */
	virtual IDbAdapter* Clone() = 0;
	
	/*! \brief Return true if adapter settings are set and adapter can connect to the database */
	virtual bool CanConnect() = 0;
	
	/*! \brief Function connect databases to the DbConnection */
	virtual void GetDatabases(DbConnection* dbCon) = 0;

	/*! \brief Function connect tables to the Database */
	virtual void GetTables(Database* db, bool includeViews) = 0;
	
	/*! \brief Function connect views to the Database */
	virtual void GetViews(Database* db) = 0;
	
	/*! \brief Function connect columns to the DBETable */
	virtual bool GetColumns(DBETable* pTab) = 0;
	
	
	/*! \brief Return wxString with USE DB statement for dbName */
	virtual wxString GetUseDb(const wxString& dbName) = 0;
	/*! \brief Return wxString with defalut SELECT for defined table and db */
	virtual wxString GetDefaultSelect(const wxString& dbName, const wxString& tableName) = 0;
	virtual wxString GetDefaultSelect(const wxString& cols, const wxString& dbName, const wxString& tableName) = 0;
	/*! \brief Return Create table sql statement */
	virtual wxString GetCreateTableSql(DBETable* tab, bool dropTable) = 0;	
	/*! \brief Return Create view sql statement */
	virtual wxString GetCreateViewSql(View* view, bool dropView) = 0;		
	/*! \brief Return Create update table SQL statement for adding constraints */
	virtual wxString GetAlterTableConstraintSql(DBETable* tab) = 0;
	/*! \brief Return Create database SQL statement. */
	virtual wxString GetCreateDatabaseSql(const wxString& dbName) = 0;
	/*! \brief Return Drop table SQL statement. */
	virtual wxString GetDropTableSql(DBETable* pTab) = 0;
	/*! \brief Return Drop database SQL statement. */
	virtual wxString GetDropDatabaseSql(Database* pDb) = 0;	

	virtual void CloseConnection() = 0;
	
	/*! \brief Return IDbType by name string */
	virtual IDbType* GetDbTypeByName(const wxString& typeName) = 0;
	/*! \brief Return IDbType by name universal name */
	virtual IDbType* GetDbTypeByUniversalName(IDbType::UNIVERSAL_TYPE type) = 0;
	/*! \brief Return wxArrayString of possible db types */
	virtual wxArrayString* GetDbTypes () = 0;

	/*! \brief Convert IDbType to the special db type. (!!! Old type is deleted !!!) */
	virtual IDbType* ConvertType (IDbType* pType) = 0;
	/*! \brief Return wxArrayString of possible db types */
	virtual void ConvertTable(DBETable* pTab) = 0;
	
	const TYPE& GetAdapterType() const {return m_adapterType;}
	
protected:
	TYPE m_adapterType;

};

#endif // IDBADAPTER_H

==> codelite-5.1-gtk.src.tar.gz: codelite-5.1/DatabaseExplorer/IDbAdapter.h <==
#ifndef IDBADAPTER_H
#define IDBADAPTER_H
#include <wx/wx.h>
#include "smart_ptr.h"
#include <wx/dynarray.h>
#include <wx/dblayer/include/DatabaseLayer.h>
#include "IDbType.h"
//#include "columncol.h"
//#include "tablecol.h"
//#include "databasecol.h"
class DbConnection;
class Database;
class DBETable;
class View;
class IDbType;


typedef SmartPtr<DatabaseLayer> DatabaseLayerPtr;

/*! \brief Basic virtual class for creating universal interface between different database servers. */
class IDbAdapter {

public:
	enum TYPE {
		atUNKNOWN = 0,
		atSQLITE,
		atMYSQL,
		atPOSTGRES
	};
	
	/*! \brief Return opened DatabaseLayer for selected database. If dbName is empty, DatabaseLayer will be opend without defalut database. */
	virtual DatabaseLayerPtr GetDatabaseLayer(const wxString& dbName) = 0;
	
	/*! \brief Return true if dbAdapter is connected. DEPRECATED!!! */
	virtual bool IsConnected() = 0;
	
	/*! \brief Clone DbAdapter and return new object */
	virtual IDbAdapter* Clone() = 0;
	
	/*! \brief Return true if adapter settings are set and adapter can connect to the database */
	virtual bool CanConnect() = 0;
	
	/*! \brief Function connect databases to the DbConnection */
	virtual void GetDatabases(DbConnection* dbCon) = 0;

	/*! \brief Function connect tables to the Database */
	virtual void GetTables(Database* db, bool includeViews) = 0;
	
	/*! \brief Function connect views to the Database */
	virtual void GetViews(Database* db) = 0;
	
	/*! \brief Function connect columns to the DBETable */
	virtual bool GetColumns(DBETable* pTab) = 0;
	
	
	/*! \brief Return wxString with USE DB statement for dbName */
	virtual wxString GetUseDb(const wxString& dbName) = 0;
	/*! \brief Return wxString with defalut SELECT for defined table and db */
	virtual wxString GetDefaultSelect(const wxString& dbName, const wxString& tableName) = 0;
	virtual wxString GetDefaultSelect(const wxString& cols, const wxString& dbName, const wxString& tableName) = 0;
	/*! \brief Return Create table sql statement */
	virtual wxString GetCreateTableSql(DBETable* tab, bool dropTable) = 0;	
	/*! \brief Return Create view sql statement */
	virtual wxString GetCreateViewSql(View* view, bool dropView) = 0;		
	/*! \brief Return Create update table SQL statement for adding constraints */
	virtual wxString GetAlterTableConstraintSql(DBETable* tab) = 0;
	/*! \brief Return Create database SQL statement. */
	virtual wxString GetCreateDatabaseSql(const wxString& dbName) = 0;
	/*! \brief Return Drop table SQL statement. */
	virtual wxString GetDropTableSql(DBETable* pTab) = 0;
	/*! \brief Return Drop database SQL statement. */
	virtual wxString GetDropDatabaseSql(Database* pDb) = 0;	

	virtual void CloseConnection() = 0;
	
	/*! \brief Return IDbType by name string */
	virtual IDbType* GetDbTypeByName(const wxString& typeName) = 0;
	/*! \brief Return IDbType by name universal name */
	virtual IDbType* GetDbTypeByUniversalName(IDbType::UNIVERSAL_TYPE type) = 0;
	/*! \brief Return wxArrayString of possible db types */
	virtual wxArrayString* GetDbTypes () = 0;

	/*! \brief Convert IDbType to the special db type. (!!! Old type is deleted !!!) */
	virtual IDbType* ConvertType (IDbType* pType) = 0;
	/*! \brief Return wxArrayString of possible db types */
	virtual void ConvertTable(DBETable* pTab) = 0;
	
	const TYPE& GetAdapterType() const {return m_adapterType;}
	
protected:
	TYPE m_adapterType;

};

#endif // IDBADAPTER_H
